@@ -183,8 +183,7 @@ class StandardizeReaction:
         """
         Fix atom-to-atom mapping of some functional groups. Return True if found AAM errors.
         """
-        if logging:
-            log = []
+        log = []
         seen = set()
         if not self:
             return False
@@ -192,7 +191,7 @@ class StandardizeReaction:
         for r_pattern, p_pattern, fix in mapping_rules:
             found = []
             for m in self.reactants:
-                for mapping in r_pattern.get_mapping(m, optimize=False, automorphism_filter=False):
+                for mapping in r_pattern.get_mapping(m, automorphism_filter=False):
                     if mapping[1] not in seen:
                         found.append(({fix.get(k, k): v for k, v in mapping.items()},
                                       {mapping[k]: mapping[v] for k, v in fix.items()}))
@@ -200,7 +199,7 @@ class StandardizeReaction:
             if not found:
                 continue
             for m in self.products:
-                for mapping in p_pattern.get_mapping(m, optimize=False, automorphism_filter=False):
+                for mapping in p_pattern.get_mapping(m, automorphism_filter=False):
                     atom = mapping[1]
                     if atom in seen:
                         continue
@@ -213,8 +212,7 @@ class StandardizeReaction:
                     del found[n]
                     m.remap(v)
                     seen.add(atom)
-                    if logging:
-                        log.append(('group remap', list(v)))
+                    log.append(('group remap', list(v)))
         if seen:
             self.flush_cache()
             flag = True
@@ -230,7 +228,7 @@ class StandardizeReaction:
             del self.__dict__['__cached_method_compose']
 
             flag_m = False
-            for mapping in bad_query.get_mapping(cgr, optimize=False, automorphism_filter=False):
+            for mapping in bad_query.get_mapping(cgr, automorphism_filter=False):
                 if not seen.isdisjoint(mapping.values()):  # prevent matching same RC
                     continue
                 mapping = {mapping[n]: next(free_number) if m is None else mapping[m] for n, m in fix.items()}
@@ -246,8 +244,7 @@ class StandardizeReaction:
                 for m in good_query.get_mapping(check, automorphism_filter=False):
                     if valid.issubset(m) and delta.issubset(m.values()):
                         seen.update(mapping)
-                        if logging:
-                            log.append((rule_num, str(bad_query), str(good_query), tuple(mapping.values())))
+                        log.append((rule_num, str(bad_query), str(good_query), tuple(mapping.values())))
                         flag = True
                         break
                 else:
@@ -259,7 +256,7 @@ class StandardizeReaction:
                     continue
                 break
             else:
-                if logging and flag_m:
+                if flag_m:
                     log.append((rule_num, str(bad_query), str(good_query), ()))
         if seen:
             self.flush_cache()
