@@ -215,8 +215,7 @@ class Element(Core, ABC):
         compare attached to molecules elements
         """
         return isinstance(other, Element) and self.atomic_number == other.atomic_number and \
-            self.isotope == other.isotope and self.charge == other.charge and self.is_radical == other.is_radical and \
-            self.implicit_hydrogens == other.implicit_hydrogens
+            self.isotope == other.isotope and self.charge == other.charge and self.is_radical == other.is_radical
 
     def __hash__(self):
         return hash((self.isotope or 0, self.atomic_number, self.charge, self.is_radical, self.implicit_hydrogens or 0))
@@ -307,24 +306,29 @@ class Element(Core, ABC):
                 rules[(charge, is_radical, explicit)].append((explicit_set, explicit_dict, 0))
         return dict(rules)
 
+    @class_cached_property
+    def _compiled_saturation_rules(self) -> List[Tuple[int, bool, int, int, Optional[Dict[Tuple[int, int], int]]]]:
+        """
+        dictionary with key = (charge, is_radical, sum_of_bonds) and
+        value = list of possible neighbors
+        """
+        elements_classes = {x.__name__: x.atomic_number.fget(None) for x in Element.__subclasses__()}
 
-# averaged isotopes. 3.*-compatibility
-isotopes = tuple(map(int, '''  1                                                                   4
-                               7   9                                          11  12  14  16  19  20
-                              23  24                                          27  28  31  32  35  40
-                              39  40  45  48  51  52  55  56  59  59  64  65  70  73  75  79  80  84
-                              85  88  89  91  93  96  98 101 103 106 108 112 115 119 122 128 127 131
-                             133 137 139
+        rules = []
+        for valence in self._common_valences:
+            rules.append((0, False, valence, 0, None))  # any atoms and bonds possible
 
-                                     140 141 144 145 150 152 157 159 163 165 167 169 173 175
-
-                                         178 181 184 186 190 192 195 197 201 204 207 209 209 210 222 
-                             223 226 227
-
-                                     232 231 238 237 244 243 247 247 251 252 257 258 259 260
-
-                                         261 270 269 270 270 278 281 281 285 278 289 289 293 297 294
-                          '''.split()))
+        for charge, is_radical, implicit, environment in self._valences_exceptions:
+            if not environment:
+                rules.append((charge, is_radical, implicit, 0, None))
+            else:
+                explicit_dict = defaultdict(int)
+                explicit = 0
+                for b, e in environment:
+                    explicit_dict[(b, elements_classes[e])] += 1
+                    explicit += b
+                rules.append((charge, is_radical, implicit + explicit, implicit, dict(explicit_dict)))
+        return rules
 
 
 __all__ = ['Element']
